GFinitialise: GFinitialise function
Description
Generic function defining the the initialisation step for the gridFunction class of objects.
The function is called invisibly within MALAlgcp and facilitates the dumping of data to disk
Usage
GFinitialise(F, ...)
Value
method GFinitialise