Learn R Programming

lgcp (version 0.9-1)

as.owinlist.SpatialPolygonsDataFrame: as...

Description

as.owinlist.SpatialPolygonsDataFrame function

Usage

## S3 method for class 'SpatialPolygonsDataFrame':
as.owinlist(obj, dmin=0,
    check=TRUE, ...)

Arguments

obj
a SpatialPolygonsDataFrame object
dmin
purpose is to simplify the SpatialPolygons. A numeric value giving the smallest permissible length of an edge. See ? simplify.owin
check
whether or not to use spatstat functions to check the validity of SpatialPolygons objects
...
additional arguments

Value

  • a list of owin objects corresponding to the constituent Polygons objects

Details

A function to create a list of owin objects from a SpatialPolygonsDataFrame