Learn R Programming

lgcp (version 1.3-14)

as.owinlist.stapp: as.owinlist.stapp function

Description

A function to create a list of owin objects from a stapp

Usage

"as.owinlist"(obj, dmin = 0, check = TRUE, ...)

Arguments

obj
an stapp object
dmin
purpose is to simplify the SpatialPolygons. A numeric value giving the smallest permissible length of an edge. See ? simplify.owin
check
whether or not to use spatstat functions to check the validity of SpatialPolygons objects
...
additional arguments

Value

a list of owin objects corresponding to the constituent Polygons objects