Learn R Programming

lgcp (version 1.3-14)

circulant.matrix: circulant.matrix function

Description

If x is a matrix whose columns are the bases of the sub-blocks of a block circulant matrix, then this function returns the block circulant matrix of interest.

Usage

"circulant"(x, ...)

Arguments

x
a matrix object
...
additional arguments

Value

If x is a matrix whose columns are the bases of the sub-blocks of a block circulant matrix, then this function returns the block circulant matrix of interest.