Rdocumentation
powered by
Learn R Programming
lgcp (version 1.3-14)
discreteWindow.lgcpPredict: discreteWindow.lgcpPredict function
Description
A function for extracting the FFT discrete window from an lgcpPredict object.
Usage
"discreteWindow"(obj, inclusion = "touching", ...)
Arguments
obj
an lgcpPredict object
inclusion
criterion for cells being included into observation window. Either 'touching' or 'centroid'. The former includes all cells that touch the observation window, the latter includes all cells whose centroids are inside the observation window.
...
additional arguments
Value
...