Learn R Programming

lgcp (version 1.3-14)

getRotation.stppp: getRotation.stppp function

Description

Compute rotation matrix if observation window is a polygonal boundary

Usage

"getRotation"(xyt, ...)

Arguments

xyt
an object of class stppp
...
additional arguments

Value

the optimal rotation matrix and rotated data and observation window. Note it may or may not be advantageous to rotate the window, this information is displayed prior to the MALA routine when using lgcpPredict