Learn R Programming

lgcp (version 0.9-2)

ginhomAverage: ginhomAverage function...

Description

ginhomAverage function

Usage

ginhomAverage(xyt, spatial.intensity, temporal.intensity,
    time.window=xyt$tlim, rvals, correction="iso",
    suppresswarnings=FALSE)

Arguments

xyt
an object of class stppp
spatial.intensity
A spatialAtRisk object
temporal.intensity
A temporalAtRisk object
time.window
time interval contained in the interval xyt$tlim over which to compute average. Useful if there is a lot of data over a lot of time points.
rvals
Vector of values for the argument r at which g(r) should be evaluated (see ?pcfinhom). There is a sensible default.
correction
choice of edge correction to use, see ?pcfinhom, default is Ripley isotropic correction
suppresswarnings
Whether or not to suppress warnings generated by pcfinhom

Value

  • time average of inhomogenous pcf, equation (13) of Brix and Diggle 2001.

Details

A function to estimate the inhomogeneous pair correlation function for a spatiotemporal point process. See equation (8) of Diggle P, Rowlingson B, Su T (2005).

References

  1. Baddeley AJ, Moller J, Waagepetersen R (2000). Non-and semi-parametric estimation of interaction in inhomogeneous point patterns. Statistica Neerlandica, 54, 329-350.
  2. Brix A, Diggle PJ (2001). Spatiotemporal Prediction for log-Gaussian Cox processes. Journal of the Royal Statistical Society, Series B, 63(4), 823-841.
  3. Diggle P, Rowlingson B, Su T (2005). Point Process Methodology for On-line Spatio-temporal Disease Surveillance. Environmetrics, 16(5), 423-434.

See Also

KinhomAverage, spatialparsEst, thetaEst, lambdaEst, muEst