Rdocumentation
powered by
Learn R Programming
lgcp (version 1.3-14)
gridav.lgcpPredict: gridav.lgcpPredict function
Description
Accessor function for
lgcpPredict objects
: returns the
gridmeans
argument set in the
output.control
argument of the function
lgcpPredict
.
Usage
"gridav"(obj, fun = NULL, ...)
Arguments
obj
an object of class lgcpPredict
fun
an optional character vector of length 1 giving the name of a function to return Monte Carlo average of
...
additional arguments
Value
returns the output from the gridmeans option of the setoutput argument of lgcpPredict
See Also
setoutput
,
lgcpgrid