initialiseAMCMC: initialiseAMCMC function
Description
A generic to be used for the purpose of user-defined adaptive MCMC schemes,
initialiseAMCMC tells the MALA algorithm which value of h to use first. See
lgcp vignette, codevignette("lgcp"), for further details on writing adaptive MCMC schemes.
Usage
initialiseAMCMC(obj, ...)
Value
method intialiseAMCMC