lgcpPredict performs spatiotemporal
prediction for log-Gaussian Cox ProcesseslgcpPredict(xyt, T, laglength,
model.parameters = lgcppars(),
spatial.covmodel = "exponential", covpars = c(),
cellwidth = NULL, gridsize = NULL, spatial.intensity,
temporal.intensity, mcmc.control,
output.control = setoutput(),
missing.data.areas = NULL, autorotate = FALSE,
gradtrunc = Inf, ext = 2, inclusion = "touching")lgcpPredictLet $\mathcal Y(s,t)$ be a spatiotemporal Gaussian process, $W\subset R^2$ be an observation window in space and $T\subset R_{\geq 0}$ be an interval of time of interest. Cases occur at spatio-temporal positions $(x,t) \in W \times T$ according to an inhomogeneous spatio-temporal Cox process, i.e. a Poisson process with a stochastic intensity $R(x,t)$, The number of cases, $X_{S,[t_1,t_2]}$, arising in any $S \subseteq W$ during the interval $[t_1,t_2]\subseteq T$ is then Poisson distributed conditional on $R(\cdot)$, $$X_{S,[t_1,t_2]} \sim \mbox{Poisson}\left{\int_S\int_{t_1}^{t_2} R(s,t)d sd t\right}$$ Following Brix and Diggle (2001) and Diggle et al (2005), the intensity is decomposed multiplicatively as $$R(s,t) = \lambda(s)\mu(t)\exp{\mathcal Y(s,t)}.$$ In the above, the fixed spatial component, $\lambda:R^2\mapsto R_{\geq 0}$, is a known function, proportional to the population at risk at each point in space and scaled so that $$\int_W\lambda(s)d s=1,$$ whilst the fixed temporal component, $\mu:R_{\geq 0}\mapsto R_{\geq 0}$, is also a known function with $$\mu(t) \delta t = E[X_{W,\delta t}],$$ for $t$ in a small interval of time, $\delta t$, over which the rate of the process over $W$ can be considered constant.
NOTE: the xyt stppp object can be recorded in
continuous time, but for the purposes of prediciton,
discretisation must take place. For the time dimension,
this is achieved invisibly by as.integer(xyt$t)
and as.integer(xyt$tlim). Therefore, before
running an analysis please make sure that this is
commensurate with the physical inerpretation and
requirements of your output. The spatial discretisation
is chosen with the argument cellwidth (or gridsize). If
the chosen discretisation in time and space is too coarse
for a given set of parameters (sigma, phi and theta) then
the proper correlation structures implied by the model
will not be captured in the output.
Before calling this function, the user must decide on the time point of interest, the number of intervals of data to use, the parameters, spatial covariance model, spatial discretisation, fixed spatial ($\lambda(s)$) and temporal ($\mu(t)$) components, mcmc parameters, and whether or not any output is required.