Learn R Programming

lgcp (version 0.9-2)

lgcpgrid: lgcpgrid function...

Description

lgcpgrid function

Usage

lgcpgrid(grid, ...)

Arguments

grid
a list object with each member of the list being a numeric matrix, each matrix having the same dimension
...
other arguments

Value

  • method lgcpgrid

Details

Generic function for the hadling of list objects where each element of the list is a matrix. Each matrix is assumed to have the same dimension. Such objects arise from the various routines in the package lgcp.