Learn R Programming

lgcp (version 0.9-2)

lgcpgrid.list: lgcpgrid...

Description

lgcpgrid.list function

Usage

## S3 method for class 'list':
lgcpgrid(grid, ...)

Arguments

grid
a list object with each member of the list being a numeric matrix, each matrix having the same dimension
...
other arguments

Value

  • an object of class lgcpgrid

Details

Creates an lgcpgrid object from a list object. Note that each element of the list should be a matrix, and that each matrix should have the same dimension.

See Also

lgcpgrid.array, as.list.lgcpgrid, print.lgcpgrid, summary.lgcpgrid, quantile.lgcpgrid, image.lgcpgrid, plot.lgcpgrid