Converts a polygon selected via the mouse in a graphics
window into an polygonal owin object. (Make sure the x
and y scales are correct!) Points must be selected
traversing the required window in one direction (ie
either clockwise, or anticlockwise), points must not be
overlapping. Select the sequence of edges via left mouse
button clicks and store the polygon with a right click.
Usage
loc2poly(n = 512, type = "l", col = "black", ...)
Arguments
n
the maximum number of points to locate
type
same as argument type in function locator.
see ?locator. Default draws lines