Description
Generic function used in the construction of marked
space-time planar point patterns. An mstppp object is
like an stppp object, but with an extra component
containing a data frame (the mark information).Details
Observations are assumed to occur in the plane and the
observation window is assumed not to change over time.