Learn R Programming

lgcp (version 1.3-14)

mstppp.list: mstppp.list function

Description

Construct a marked space-time planar point pattern from a list object

Usage

"mstppp"(P, ...)

Arguments

P
list object containing $xyt, an (n x 3) matrix corresponding to (x,y,t) values; $tlim, a vector of length 2 givign the observation time window, $window giving an owin spatial observation winow, see ?owin for more details, and $data, a data frame containing the collection of marks
...
additional arguments

Value

an object of class mstppp

See Also

mstppp, mstppp.ppp,