A function to compute the precision matrix of a GMRF on
an M x N toral grid with neighbourhood size ns. Note that
the precision matrix is block circulant. The returned
function operates on a parameter vector as in Rue and
Held (2005) pp 187.
Usage
paramprec(ns, M, N)
Arguments
ns
neighbourhood size
M
number of cells in x direction
N
number of cells in y direction
Value
a function that returns the precision matrix given a
parameter vector.