Learn R Programming

lgcp (version 1.3-14)

parautocorr: parautocorr function

Description

A function to produce autocorrelation plots for the paramerers beta and eta from a call to the function lgcpPredictSpatialPlusPars, lgcpPredictAggregateSpatialPlusPars, lgcpPredictSpatioTemporalPlusPars or lgcpPredictMultitypeSpatialPlusPars

Usage

parautocorr(obj, xlab = "Lag", ylab = NULL, main = "", ask = TRUE, ...)

Arguments

obj
an object produced by a call to lgcpPredictSpatialPlusPars, lgcpPredictAggregateSpatialPlusPars, lgcpPredictSpatioTemporalPlusPars orlgcpPredictMultitypeSpatialPlusPars
xlab
optional label for x-axis, there is a sensible default.
ylab
optional label for y-axis, there is a sensible default.
main
optional title of the plot, there is a sensible default.
ask
the paramter "ask", see ?par
...
other arguments passed to the function "hist"

Value

produces autocorrelation plots of the parameters beta and eta

See Also

ltar, autocorr, traceplots, parsummary, textsummary, priorpost, postcov, exceedProbs, betavals, etavals