Learn R Programming

lgcp (version 1.3-14)

priorpost: priorpost function

Description

A function to plot the prior and posterior densities of the model parameters eta and beta. The prior appears as a red line and the posterior appears as a histogram.

Usage

priorpost(obj, breaks = 30, xlab = NULL, ylab = "Density", main = "", ask = TRUE, ...)

Arguments

obj
an object produced by a call to lgcpPredictSpatialPlusPars, lgcpPredictAggregateSpatialPlusPars, lgcpPredictSpatioTemporalPlusPars or lgcpPredictMultitypeSpatialPlusPars
breaks
"breaks" paramter from the function "hist"
xlab
optional label for x-axis, there is a sensible default.
ylab
optional label for y-axis, there is a sensible default.
main
optional title of the plot, there is a sensible default.
ask
the paramter "ask", see ?par
...
other arguments passed to the function "hist"

Value

plots of the prior and posterior of the model parameters eta and beta.

See Also

ltar, autocorr, parautocorr, traceplots, parsummary, textsummary, postcov, exceedProbs, betavals, etavals