Learn R Programming

lgcp (version 1.3-14)

roteffgain: roteffgain function

Description

Compute whether there might be any advantage in rotating the observation window in the object xyt for a proposed cell width.

Usage

roteffgain(xyt, cellwidth)

Arguments

xyt
an object of class stppp
cellwidth
size of grid on which to do MALA

Value

whether or not there woud be any efficiency gain in the MALA by rotating window

See Also

getRotation.stppp