Learn R Programming

lgcp (version 1.3-14)

seintens.lgcpPredict: seintens.lgcpPredict function

Description

Accessor function returning the standard error of the Poisson intensity as an lgcpgrid object.

Usage

"seintens"(obj, ...)

Arguments

obj
an lgcpPredict object
...
additional arguments

Value

the cell-wise standard error of the Poisson intensity, as computed by MCMC.

See Also

lgcpPredict