Rdocumentation
powered by
Learn R Programming
lgcp (version 1.3-14)
serr.lgcpPredict: serr.lgcpPredict function
Description
Accessor function returning the standard error of relative risk as an lgcpgrid object.
Usage
"serr"(obj, ...)
Arguments
obj
an lgcpPredict object
...
additional arguments
Value
Standard error of the relative risk as computed by MCMC.
See Also
lgcpPredict