Learn R Programming

lgcp (version 1.3-14)

showGrid.default: showGrid.default function

Description

Default method for printing a grid to a screen. Arguments are vectors giving the x any y coordinates of the centroids.

Usage

"showGrid"(x, y, ...)

Arguments

x
an vector of grid values for the x coordinates
y
an vector of grid values for the y coordinates
...
additional arguments passed to points

Value

plots grid centroids on the current graphics device

See Also

showGrid.lgcpPredict, showGrid.stppp