Learn R Programming

lgcp (version 1.3-14)

showGrid.lgcpPredict: showGrid.lgcpPredict function

Description

This function displays the FFT grid used on a plot of an lgcpPredict object. First plot the object using for example plot(lg), where lg is an object of class lgcpPredict, then for any of the plots produced, a call to showGrid(lg,pch=="+",cex=0.5) will display the centroids of the FFT grid.

Usage

"showGrid"(x, ...)

Arguments

x
an object of class lgcpPredict
...
additional arguments passed to points

Value

plots grid centroids on the current graphics device

See Also

lgcpPredict, showGrid.default, showGrid.stppp