Learn R Programming

lgcp (version 1.3-14)

spatialIntensities.fromXYZ: spatialIntensities.fromXYZ function

Description

Extract the spatial intensities from an object of class fromXYZ (as would have been created by spatialAtRisk for example).

Usage

"spatialIntensities"(X, xyt, ...)

Arguments

X
object of class fromXYZ
xyt
object of class stppp or a list object of numeric vectors with names $x, $y
...
additional arguments

Value

normalised spatial intensities

See Also

spatialIntensities, spatialIntensities.fromSPDF