Learn R Programming

lgcp (version 0.9-2)

spatialparsEst: spatialparsEst function...

Description

spatialparsEst function

Usage

spatialparsEst(gk, sigma.range, phi.range)

Arguments

gk
an R object; output from the function KinhomAverage or ginhomAverage
sigma.range
range of sigma values to consider
phi.range
range of phi values to consider

Value

  • rpanel function to help choose sigma nad phi by eye

Details

Having estimated either the pair correlation or K functions using respectively ginhomAverage or KinhomAverage, the spatial parameters sigma and phi can be estimated. This function provides a visual tool for this estimation procedure.

References

  1. Baddeley AJ, Moller J, Waagepetersen R (2000). Non-and semi-parametric estimation of interaction in inhomogeneous point patterns. Statistica Neerlandica, 54, 329-350.
  2. Brix A, Diggle PJ (2001). Spatiotemporal Prediction for log-Gaussian Cox processes. Journal of the Royal Statistical Society, Series B, 63(4), 823-841.
  3. Diggle P, Rowlingson B, Su T (2005). Point Process Methodology for On-line Spatio-temporal Disease Surveillance. Environmetrics, 16(5), 423-434.

See Also

ginhomAverage, KinhomAverage, thetaEst, lambdaEst, muEst