Rdocumentation
powered by
Learn R Programming
lgcp (version 1.3-14)
summary.mcmc: summary.mcmc function
Description
summary of an mcmc iterator print out values of an iterator and reset it. DONT call this in a loop that uses this iterator - it will reset it. And break.
Usage
"summary"(object, ...)
Arguments
object
an mcmc iterator
...
other args