Learn R Programming

lgcp (version 0.9-2)

target.and.grad: target...

Description

target.and.grad function

Usage

target.and.grad(at.mat.list, theta, varvals, nicounts.mat.list,
    timediffs, car.mat, mu, spatial.mat, temporal, lam.tilde, cin,
    M.ext, N.ext, gradtrunc, estgradtrunc=FALSE)

Arguments

at.mat.list
list of matrices
theta
parameter beta, see Brix and Diggle (2001)
varvals
variances, pre-computed
nicounts.mat.list
list of matrices of ni counts
timediffs
vector of delta ts
car.mat
matrix
mu
mean parameter, see Brix and Diggle
spatial.mat
fixed spatial component, output from function fftgrid
temporal
fixed temporal component
lam.tilde
transpose of Fourier transform on extended grid, output from function fftgrid
cin
cellInside, output from function fftgrid
M.ext
number of x 'gridlines' in extended space
N.ext
number of y 'gridlines' in extended space
gradtrunc
truncation for gradient vector equal to H parameter Moller et al 1998 pp 473. Set to zero for no gradient truncation (default).
estgradtrunc
set to true if estimating gradient truncation, see ?computeGradtrunc

Value

  • The log target and gradient