Learn R Programming

lgcp (version 1.3-14)

traceplots: traceplots function

Description

A function to produce trace plots for the paramerers beta and eta from a call to the function lgcpPredictSpatialPlusPars, lgcpPredictAggregateSpatialPlusPars, lgcpPredictSpatioTemporalPlusPars or lgcpPredictMultitypeSpatialPlusPars

Usage

traceplots(obj, xlab = "Sample No.", ylab = NULL, main = "", ask = TRUE, ...)

Arguments

obj
an object produced by a call to lgcpPredictSpatialPlusPars, lgcpPredictAggregateSpatialPlusPars, lgcpPredictSpatioTemporalPlusPars orlgcpPredictMultitypeSpatialPlusPars
xlab
optional label for x-axis, there is a sensible default.
ylab
optional label for y-axis, there is a sensible default.
main
optional title of the plot, there is a sensible default.
ask
the paramter "ask", see ?par
...
other arguments passed to the function "hist"

Value

produces MCMC trace plots of the parameters beta and eta

See Also

ltar, autocorr, parautocorr, parsummary, textsummary, priorpost, postcov, exceedProbs, betavals, etavals