Learn R Programming

lgcp (version 1.3-14)

varfield.lgcpPredict: varfield.lgcpPredict function

Description

This is an accessor function for objects of class lgcpPredict and returns the variance of the field Y as an lgcpgrid object.

Usage

"varfield"(obj, ...)

Arguments

obj
an object of class lgcpPredict
...
additional arguments

Value

returns the cell-wise variance of Y computed via Monte Carlo.

See Also

lgcpPredict