GFinitialise: GFinitialise function...
Description
GFinitialise functionUsage
GFinitialise(F, ...)
Details
Generic function defining the the initialisation step for the gridFunction class of objects.
The function is called invisibly within MALAlgcp and facilitates the dumping of data to disk