circulant.matrix: circulant.matrix function
Description
If x is a matrix whose columns are the bases of the sub-blocks of a block circulant matrix, then this function returns the
block circulant matrix of interest.
Value
If x is a matrix whose columns are the bases of the sub-blocks of a block circulant matrix, then this function returns the block circulant matrix of interest.