A function to estimate the inhomogeneous pair correlation
function for a spatiotemporal point process. See equation
(8) of Diggle P, Rowlingson B, Su T (2005).
time interval contained in the
interval xyt$tlim over which to compute average. Useful
if there is a lot of data over a lot of time points.
rvals
Vector of values for the argument r at which
g(r) should be evaluated (see ?pcfinhom). There is a
sensible default.
correction
choice of edge correction to use, see
?pcfinhom, default is Ripley isotropic correction
suppresswarnings
Whether or not to suppress
warnings generated by pcfinhom
...
other parameters to be passed to pcfinhom, see
?pcfinhom
Value
time average of inhomogenous pcf, equation (13) of Brix
and Diggle 2001.
References
Benjamin M. Taylor, Tilman M. Davies,
Barry S. Rowlingson, Peter J. Diggle (2013). Journal of
Statistical Software, 52(4), 1-40. URL
http://www.jstatsoft.org/v52/i04/
Baddeley AJ,
Moller J, Waagepetersen R (2000). Non-and semi-parametric
estimation of interaction in inhomogeneous point
patterns. Statistica Neerlandica, 54, 329-350.
Brix A, Diggle PJ (2001). Spatiotemporal Prediction for
log-Gaussian Cox processes. Journal of the Royal
Statistical Society, Series B, 63(4), 823-841.
Diggle P, Rowlingson B, Su T (2005). Point Process
Methodology for On-line Spatio-temporal Disease
Surveillance. Environmetrics, 16(5), 423-434.