Rdocumentation
powered by
Learn R Programming
lgcp (version 1.3-14)
hvals.lgcpPredict: hvals.lgcpPredict function
Description
Accessor function returning the value of $h$, the MALA proposal scaling constant over the iterations of the algorithm for objects of class
lgcpPredict
Usage
"hvals"(obj, ...)
Arguments
obj
an object of class lgcpPredict
...
additional arguments
Value
returns the values of h taken during the progress of the algorithm
See Also
lgcpPredict