vector of time points for prediction. Must start strictly after last inferred time point.
Value
forcasted Y values over grid
Details
Function to produce forecasts for the mean field $Y$ at times beyond the last time point in the
analysis (given by the argument T in the function lgcpPredict).
References
Brix A, Diggle PJ (2001). Spatiotemporal Prediction for log-Gaussian Cox processes. Journal of the Royal Statistical Society, Series B, 63(4), 823-841.