## S3 method for class 'list':
lgcpgrid(grid, ...)
Arguments
grid
a list object with each member of the list being a numeric matrix, each matrix having the same dimension
...
other arguments
Value
an object of class lgcpgrid
Details
Creates an lgcpgrid object from a list object. Note that each element of the list should be a matrix,
and that each matrix should have the same dimension.