Rdocumentation
powered by
Learn R Programming
lgcp (version 1.3-2)
plot.lgcpZmat: plot.lgcpZmat function
Description
A function to plot lgcpZmat objects
Usage
## S3 method for class 'lgcpZmat': plot(x, ask = TRUE, pow = 1, main = NULL, ...)
Arguments
x
an lgcpZmat object, see ?getZmat
ask
graphical parameter ask, see ?par
pow
power parameter, raises the image values to this power (helps with visualisation, default is 1.)
main
title for plot, default is null which gives an automatic title to the plot (the name of the covariate)
...
other paramters
Value
a sequence of plots of the interpolated covariate values