Arguments
x
an object of class lgcpPredict
qt
a vector of the required quantiles
tidx
the index number of the the time interval of interest, default is the last time point.
fun
a 1-1 function (default the identity function) to be applied cell-wise to the grid. Must be able to evaluate sapply(vec,fun) for vectors vec.
inWindow
an observation owin window on which to compute the quantiles, can speed up calculation. Default is x$xyt$window.
crop2parentwindow
logical: whether to only compute the quantiles for cells inside x$xyt$window (the 'parent window')