A wrapper function for stapp.SpatialPolygonsDataFrame
Usage
## S3 method for class 'list':
stapp(obj, ...)
Arguments
obj
an list object as described above, see
?stapp.SpatialPolygonsDataFrame for further details on
the requirements of the list
...
additional arguments
Value
an object of class stapp
Details
Construct a space-time aggregated point-process (stapp)
object from a list object. The first element of the list
should be a SpatialPolygonsDataFrame, the second element
of the list a counts matrix, the third element of the
list a vector of times, the fourth element a vector
giving the bounds of the temporal observation window and
the fifth element a spatstat owin object giving the
spatial observation window.